@@ -1,198 +1,182 @@
-( cd opt/kde/share/doc/HTML/en/akregator ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/akregator ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kaddressbook ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kalarm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kalarm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libkcalgroupwise.so )
+( cd opt/kde/lib ; ln -sf libkcalgroupwise.so.4 libkcalgroupwise.so )
+( cd opt/kde/lib ; rm -rf libkcalkolab.so )
+( cd opt/kde/lib ; ln -sf libkcalkolab.so.4 libkcalkolab.so )
+( cd opt/kde/lib ; rm -rf libknodecommon.so )
+( cd opt/kde/lib ; ln -sf libknodecommon.so.4 libknodecommon.so )
+( cd opt/kde/lib ; rm -rf libkpgp.so.4 )
+( cd opt/kde/lib ; ln -sf libkpgp.so.4.4.0 libkpgp.so.4 )
+( cd opt/kde/lib ; rm -rf libakonadi-kcal_next.so )
+( cd opt/kde/lib ; ln -sf libakonadi-kcal_next.so.4 libakonadi-kcal_next.so )
+( cd opt/kde/lib ; rm -rf libkalarm_calendar.so.4 )
+( cd opt/kde/lib ; ln -sf libkalarm_calendar.so.4.4.0 libkalarm_calendar.so.4 )
+( cd opt/kde/lib ; rm -rf libkabcgroupwise.so )
+( cd opt/kde/lib ; ln -sf libkabcgroupwise.so.4 libkabcgroupwise.so )
+( cd opt/kde/lib ; rm -rf libkmailprivate.so.4 )
+( cd opt/kde/lib ; ln -sf libkmailprivate.so.4.4.0 libkmailprivate.so.4 )
+( cd opt/kde/lib ; rm -rf libkleo.so )
+( cd opt/kde/lib ; ln -sf libkleo.so.4 libkleo.so )
+( cd opt/kde/lib ; rm -rf libakregatorinterfaces.so.4 )
+( cd opt/kde/lib ; ln -sf libakregatorinterfaces.so.4.4.0 libakregatorinterfaces.so.4 )
+( cd opt/kde/lib ; rm -rf libmessagecore.so )
+( cd opt/kde/lib ; ln -sf libmessagecore.so.4 libmessagecore.so )
+( cd opt/kde/lib ; rm -rf libkalarm_calendar.so )
+( cd opt/kde/lib ; ln -sf libkalarm_calendar.so.4 libkalarm_calendar.so )
+( cd opt/kde/lib ; rm -rf libkabc_slox.so )
+( cd opt/kde/lib ; ln -sf libkabc_slox.so.4 libkabc_slox.so )
+( cd opt/kde/lib ; rm -rf libkdepim.so.4 )
+( cd opt/kde/lib ; ln -sf libkdepim.so.4.4.0 libkdepim.so.4 )
+( cd opt/kde/lib ; rm -rf libksieve.so )
+( cd opt/kde/lib ; ln -sf libksieve.so.4 libksieve.so )
+( cd opt/kde/lib ; rm -rf libkcal_resourceremote.so )
+( cd opt/kde/lib ; ln -sf libkcal_resourceremote.so.4 libkcal_resourceremote.so )
+( cd opt/kde/lib ; rm -rf libmessagelist.so.4 )
+( cd opt/kde/lib ; ln -sf libmessagelist.so.4.4.0 libmessagelist.so.4 )
+( cd opt/kde/lib ; rm -rf libkorg_stdprinting.so )
+( cd opt/kde/lib ; ln -sf libkorg_stdprinting.so.4 libkorg_stdprinting.so )
+( cd opt/kde/lib ; rm -rf libknoteskolab.so.4 )
+( cd opt/kde/lib ; ln -sf libknoteskolab.so.4.4.0 libknoteskolab.so.4 )
+( cd opt/kde/lib ; rm -rf libakregatorprivate.so.4 )
+( cd opt/kde/lib ; ln -sf libakregatorprivate.so.4.4.0 libakregatorprivate.so.4 )
+( cd opt/kde/lib ; rm -rf libkleo.so.4 )
+( cd opt/kde/lib ; ln -sf libkleo.so.4.4.0 libkleo.so.4 )
+( cd opt/kde/lib ; rm -rf libakregatorinterfaces.so )
+( cd opt/kde/lib ; ln -sf libakregatorinterfaces.so.4 libakregatorinterfaces.so )
+( cd opt/kde/lib ; rm -rf libkgroupwarebase.so )
+( cd opt/kde/lib ; ln -sf libkgroupwarebase.so.4 libkgroupwarebase.so )
+( cd opt/kde/lib ; rm -rf libkabc_groupdav.so.4 )
+( cd opt/kde/lib ; ln -sf libkabc_groupdav.so.4.4.0 libkabc_groupdav.so.4 )
+( cd opt/kde/lib ; rm -rf libkorganizer_calendar.so )
+( cd opt/kde/lib ; ln -sf libkorganizer_calendar.so.4 libkorganizer_calendar.so )
+( cd opt/kde/lib ; rm -rf libkcalkolab.so.4 )
+( cd opt/kde/lib ; ln -sf libkcalkolab.so.4.4.0 libkcalkolab.so.4 )
+( cd opt/kde/lib ; rm -rf libkslox.so )
+( cd opt/kde/lib ; ln -sf libkslox.so.4 libkslox.so )
+( cd opt/kde/lib ; rm -rf libkorganizer_interfaces.so )
+( cd opt/kde/lib ; ln -sf libkorganizer_interfaces.so.4 libkorganizer_interfaces.so )
+( cd opt/kde/lib ; rm -rf libkalarm_resources.so )
+( cd opt/kde/lib ; ln -sf libkalarm_resources.so.4 libkalarm_resources.so )
+( cd opt/kde/lib ; rm -rf libksieve.so.4 )
+( cd opt/kde/lib ; ln -sf libksieve.so.4.4.0 libksieve.so.4 )
+( cd opt/kde/lib ; rm -rf libkpgp.so )
+( cd opt/kde/lib ; ln -sf libkpgp.so.4 libkpgp.so )
+( cd opt/kde/lib ; rm -rf libkcalgroupwise.so.4 )
+( cd opt/kde/lib ; ln -sf libkcalgroupwise.so.4.4.0 libkcalgroupwise.so.4 )
+( cd opt/kde/lib ; rm -rf libkgroupwaredav.so.4 )
+( cd opt/kde/lib ; ln -sf libkgroupwaredav.so.4.4.0 libkgroupwaredav.so.4 )
+( cd opt/kde/lib ; rm -rf libkabcgroupwise.so.4 )
+( cd opt/kde/lib ; ln -sf libkabcgroupwise.so.4.4.0 libkabcgroupwise.so.4 )
+( cd opt/kde/lib ; rm -rf libkcal_groupdav.so.4 )
+( cd opt/kde/lib ; ln -sf libkcal_groupdav.so.4.4.0 libkcal_groupdav.so.4 )
+( cd opt/kde/lib ; rm -rf libkabckolab.so )
+( cd opt/kde/lib ; ln -sf libkabckolab.so.4 libkabckolab.so )
+( cd opt/kde/lib ; rm -rf libkcal_slox.so.4 )
+( cd opt/kde/lib ; ln -sf libkcal_slox.so.4.4.0 libkcal_slox.so.4 )
+( cd opt/kde/lib ; rm -rf libkabc_slox.so.4 )
+( cd opt/kde/lib ; ln -sf libkabc_slox.so.4.4.0 libkabc_slox.so.4 )
+( cd opt/kde/lib ; rm -rf libknoteskolab.so )
+( cd opt/kde/lib ; ln -sf libknoteskolab.so.4 libknoteskolab.so )
+( cd opt/kde/lib ; rm -rf libmessagecore.so.4 )
+( cd opt/kde/lib ; ln -sf libmessagecore.so.4.4.0 libmessagecore.so.4 )
+( cd opt/kde/lib ; rm -rf libkabc_groupdav.so )
+( cd opt/kde/lib ; ln -sf libkabc_groupdav.so.4 libkabc_groupdav.so )
+( cd opt/kde/lib ; rm -rf libkaddressbookprivate.so.4 )
+( cd opt/kde/lib ; ln -sf libkaddressbookprivate.so.4.4.0 libkaddressbookprivate.so.4 )
+( cd opt/kde/lib ; rm -rf libmessageviewer.so.0 )
+( cd opt/kde/lib ; ln -sf libmessageviewer.so.0.1.0 libmessageviewer.so.0 )
+( cd opt/kde/lib ; rm -rf libgwsoap.so.4 )
+( cd opt/kde/lib ; ln -sf libgwsoap.so.4.4.0 libgwsoap.so.4 )
+( cd opt/kde/lib ; rm -rf libmessageviewer.so )
+( cd opt/kde/lib ; ln -sf libmessageviewer.so.0 libmessageviewer.so )
+( cd opt/kde/lib ; rm -rf libkcal_resourceblog.so.4 )
+( cd opt/kde/lib ; ln -sf libkcal_resourceblog.so.4.4.0 libkcal_resourceblog.so.4 )
+( cd opt/kde/lib ; rm -rf libakonadi-kcal_next.so.4 )
+( cd opt/kde/lib ; ln -sf libakonadi-kcal_next.so.4.4.0 libakonadi-kcal_next.so.4 )
+( cd opt/kde/lib ; rm -rf libmimelib.so )
+( cd opt/kde/lib ; ln -sf libmimelib.so.4 libmimelib.so )
+( cd opt/kde/lib ; rm -rf libakonadi_next.so )
+( cd opt/kde/lib ; ln -sf libakonadi_next.so.4 libakonadi_next.so )
+( cd opt/kde/lib ; rm -rf libkcal_resourceblog.so )
+( cd opt/kde/lib ; ln -sf libkcal_resourceblog.so.4 libkcal_resourceblog.so )
+( cd opt/kde/lib ; rm -rf libkorganizer_calendar.so.4 )
+( cd opt/kde/lib ; ln -sf libkorganizer_calendar.so.4.4.0 libkorganizer_calendar.so.4 )
+( cd opt/kde/lib ; rm -rf libknodecommon.so.4 )
+( cd opt/kde/lib ; ln -sf libknodecommon.so.4.4.0 libknodecommon.so.4 )
+( cd opt/kde/lib ; rm -rf libgwsoap.so )
+( cd opt/kde/lib ; ln -sf libgwsoap.so.4 libgwsoap.so )
+( cd opt/kde/lib ; rm -rf libkabckolab.so.4 )
+( cd opt/kde/lib ; ln -sf libkabckolab.so.4.4.0 libkabckolab.so.4 )
+( cd opt/kde/lib ; rm -rf libkcal_slox.so )
+( cd opt/kde/lib ; ln -sf libkcal_slox.so.4 libkcal_slox.so )
+( cd opt/kde/lib ; rm -rf libkorganizer_core.so )
+( cd opt/kde/lib ; ln -sf libkorganizer_core.so.4 libkorganizer_core.so )
+( cd opt/kde/lib ; rm -rf libkorganizer_core.so.4 )
+( cd opt/kde/lib ; ln -sf libkorganizer_core.so.4.4.0 libkorganizer_core.so.4 )
+( cd opt/kde/lib ; rm -rf libkorganizerprivate.so.4 )
+( cd opt/kde/lib ; ln -sf libkorganizerprivate.so.4.4.0 libkorganizerprivate.so.4 )
+( cd opt/kde/lib ; rm -rf libkgroupwarebase.so.4 )
+( cd opt/kde/lib ; ln -sf libkgroupwarebase.so.4.4.0 libkgroupwarebase.so.4 )
+( cd opt/kde/lib ; rm -rf libmimelib.so.4 )
+( cd opt/kde/lib ; ln -sf libmimelib.so.4.4.0 libmimelib.so.4 )
+( cd opt/kde/lib ; rm -rf libkorganizer_eventviewer.so.4 )
+( cd opt/kde/lib ; ln -sf libkorganizer_eventviewer.so.4.4.0 libkorganizer_eventviewer.so.4 )
+( cd opt/kde/lib ; rm -rf libkorganizer_interfaces.so.4 )
+( cd opt/kde/lib ; ln -sf libkorganizer_interfaces.so.4.4.0 libkorganizer_interfaces.so.4 )
+( cd opt/kde/lib ; rm -rf libkcal_groupdav.so )
+( cd opt/kde/lib ; ln -sf libkcal_groupdav.so.4 libkcal_groupdav.so )
+( cd opt/kde/lib ; rm -rf libkslox.so.4 )
+( cd opt/kde/lib ; ln -sf libkslox.so.4.4.0 libkslox.so.4 )
+( cd opt/kde/lib ; rm -rf libkontactprivate.so.4 )
+( cd opt/kde/lib ; ln -sf libkontactprivate.so.4.4.0 libkontactprivate.so.4 )
+( cd opt/kde/lib ; rm -rf libkorg_stdprinting.so.4 )
+( cd opt/kde/lib ; ln -sf libkorg_stdprinting.so.4.4.0 libkorg_stdprinting.so.4 )
+( cd opt/kde/lib ; rm -rf libkgroupwaredav.so )
+( cd opt/kde/lib ; ln -sf libkgroupwaredav.so.4 libkgroupwaredav.so )
+( cd opt/kde/lib ; rm -rf libkcal_resourceremote.so.4 )
+( cd opt/kde/lib ; ln -sf libkcal_resourceremote.so.4.4.0 libkcal_resourceremote.so.4 )
+( cd opt/kde/lib ; rm -rf libkalarm_resources.so.4 )
+( cd opt/kde/lib ; ln -sf libkalarm_resources.so.4.4.0 libkalarm_resources.so.4 )
+( cd opt/kde/lib ; rm -rf libkdepim.so )
+( cd opt/kde/lib ; ln -sf libkdepim.so.4 libkdepim.so )
+( cd opt/kde/lib ; rm -rf libmessagelist.so )
+( cd opt/kde/lib ; ln -sf libmessagelist.so.4 libmessagelist.so )
+( cd opt/kde/lib ; rm -rf libakonadi_next.so.4 )
+( cd opt/kde/lib ; ln -sf libakonadi_next.so.4.4.0 libakonadi_next.so.4 )
+( cd opt/kde/lib ; rm -rf libkorganizer_eventviewer.so )
+( cd opt/kde/lib ; ln -sf libkorganizer_eventviewer.so.4 libkorganizer_eventviewer.so )
 ( cd opt/kde/share/doc/HTML/en/kjots ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kjots ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/ktimetracker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/ktimetracker ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kontact ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/knotes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/knotes ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kalarm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kalarm ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/knode ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/knode ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/blogilo ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/blogilo ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kioslave/news ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kioslave/news ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kleopatra ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kleopatra ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/akregator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/akregator ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kontact-admin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kontact-admin ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kabcclient ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kabcclient ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmail ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kmail ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/korganizer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/knode ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/knode ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/knotes ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/knotes ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kontact ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kontact ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kpilot ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kpilot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/ktimetracker ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/ktimetracker ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/lib ; rm -rf libkleopatraclientcore.so.0 )
-( cd opt/kde/lib ; ln -sf libkleopatraclientcore.so.0.2.1 libkleopatraclientcore.so.0 )
-( cd opt/kde/lib ; rm -rf libkleopatraclientcore.so )
-( cd opt/kde/lib ; ln -sf libkleopatraclientcore.so.0 libkleopatraclientcore.so )
-( cd opt/kde/lib ; rm -rf libkleopatraclientgui.so.0 )
-( cd opt/kde/lib ; ln -sf libkleopatraclientgui.so.0.2.1 libkleopatraclientgui.so.0 )
-( cd opt/kde/lib ; rm -rf libkleopatraclientgui.so )
-( cd opt/kde/lib ; ln -sf libkleopatraclientgui.so.0 libkleopatraclientgui.so )
-( cd opt/kde/lib ; rm -rf libkmailprivate.so.4 )
-( cd opt/kde/lib ; ln -sf libkmailprivate.so.4.3.0 libkmailprivate.so.4 )
-( cd opt/kde/lib ; rm -rf libkorganizer_eventviewer.so.4 )
-( cd opt/kde/lib ; ln -sf libkorganizer_eventviewer.so.4.3.0 libkorganizer_eventviewer.so.4 )
-( cd opt/kde/lib ; rm -rf libkorganizer_eventviewer.so )
-( cd opt/kde/lib ; ln -sf libkorganizer_eventviewer.so.4 libkorganizer_eventviewer.so )
-( cd opt/kde/lib ; rm -rf libkorganizer_calendar.so.4 )
-( cd opt/kde/lib ; ln -sf libkorganizer_calendar.so.4.3.0 libkorganizer_calendar.so.4 )
-( cd opt/kde/lib ; rm -rf libkorganizer_calendar.so )
-( cd opt/kde/lib ; ln -sf libkorganizer_calendar.so.4 libkorganizer_calendar.so )
-( cd opt/kde/lib ; rm -rf libkorganizer_core.so.4 )
-( cd opt/kde/lib ; ln -sf libkorganizer_core.so.4.3.0 libkorganizer_core.so.4 )
-( cd opt/kde/lib ; rm -rf libkorganizer_core.so )
-( cd opt/kde/lib ; ln -sf libkorganizer_core.so.4 libkorganizer_core.so )
-( cd opt/kde/lib ; rm -rf libkorganizerprivate.so.4 )
-( cd opt/kde/lib ; ln -sf libkorganizerprivate.so.4.3.0 libkorganizerprivate.so.4 )
-( cd opt/kde/lib ; rm -rf libkorg_stdprinting.so.4 )
-( cd opt/kde/lib ; ln -sf libkorg_stdprinting.so.4.3.0 libkorg_stdprinting.so.4 )
-( cd opt/kde/lib ; rm -rf libkorg_stdprinting.so )
-( cd opt/kde/lib ; ln -sf libkorg_stdprinting.so.4 libkorg_stdprinting.so )
-( cd opt/kde/lib ; rm -rf libkorganizer_interfaces.so.4 )
-( cd opt/kde/lib ; ln -sf libkorganizer_interfaces.so.4.3.0 libkorganizer_interfaces.so.4 )
-( cd opt/kde/lib ; rm -rf libkorganizer_interfaces.so )
-( cd opt/kde/lib ; ln -sf libkorganizer_interfaces.so.4 libkorganizer_interfaces.so )
-( cd opt/kde/lib ; rm -rf libknodecommon.so.4 )
-( cd opt/kde/lib ; ln -sf libknodecommon.so.4.3.0 libknodecommon.so.4 )
-( cd opt/kde/lib ; rm -rf libknodecommon.so )
-( cd opt/kde/lib ; ln -sf libknodecommon.so.4 libknodecommon.so )
-( cd opt/kde/lib ; rm -rf libakregatorinterfaces.so.4 )
-( cd opt/kde/lib ; ln -sf libakregatorinterfaces.so.4.3.0 libakregatorinterfaces.so.4 )
-( cd opt/kde/lib ; rm -rf libakregatorinterfaces.so )
-( cd opt/kde/lib ; ln -sf libakregatorinterfaces.so.4 libakregatorinterfaces.so )
-( cd opt/kde/lib ; rm -rf libakregatorprivate.so.4 )
-( cd opt/kde/lib ; ln -sf libakregatorprivate.so.4.3.0 libakregatorprivate.so.4 )
-( cd opt/kde/lib ; rm -rf libkaddressbookprivate.so.4 )
-( cd opt/kde/lib ; ln -sf libkaddressbookprivate.so.4.3.0 libkaddressbookprivate.so.4 )
-( cd opt/kde/lib ; rm -rf libkabcommon.so.4 )
-( cd opt/kde/lib ; ln -sf libkabcommon.so.4.3.0 libkabcommon.so.4 )
-( cd opt/kde/lib ; rm -rf libkabcommon.so )
-( cd opt/kde/lib ; ln -sf libkabcommon.so.4 libkabcommon.so )
-( cd opt/kde/lib ; rm -rf libkabinterfaces.so.4 )
-( cd opt/kde/lib ; ln -sf libkabinterfaces.so.4.3.0 libkabinterfaces.so.4 )
-( cd opt/kde/lib ; rm -rf libkabinterfaces.so )
-( cd opt/kde/lib ; ln -sf libkabinterfaces.so.4 libkabinterfaces.so )
-( cd opt/kde/lib ; rm -rf libkalarm_resources.so.4 )
-( cd opt/kde/lib ; ln -sf libkalarm_resources.so.4.3.0 libkalarm_resources.so.4 )
-( cd opt/kde/lib ; rm -rf libkalarm_resources.so )
-( cd opt/kde/lib ; ln -sf libkalarm_resources.so.4 libkalarm_resources.so )
-( cd opt/kde/lib ; rm -rf libkontactprivate.so.4 )
-( cd opt/kde/lib ; ln -sf libkontactprivate.so.4.3.0 libkontactprivate.so.4 )
-( cd opt/kde/lib ; rm -rf libkpilot.so.4 )
-( cd opt/kde/lib ; ln -sf libkpilot.so.4.3.0 libkpilot.so.4 )
-( cd opt/kde/lib ; rm -rf libkpilot.so )
-( cd opt/kde/lib ; ln -sf libkpilot.so.4 libkpilot.so )
-( cd opt/kde/lib ; rm -rf libkdepim.so.4 )
-( cd opt/kde/lib ; ln -sf libkdepim.so.4.3.0 libkdepim.so.4 )
-( cd opt/kde/lib ; rm -rf libkdepim.so )
-( cd opt/kde/lib ; ln -sf libkdepim.so.4 libkdepim.so )
-( cd opt/kde/lib ; rm -rf libkleo.so.4 )
-( cd opt/kde/lib ; ln -sf libkleo.so.4.3.0 libkleo.so.4 )
-( cd opt/kde/lib ; rm -rf libkleo.so )
-( cd opt/kde/lib ; ln -sf libkleo.so.4 libkleo.so )
-( cd opt/kde/lib ; rm -rf libkpgp.so.4 )
-( cd opt/kde/lib ; ln -sf libkpgp.so.4.3.0 libkpgp.so.4 )
-( cd opt/kde/lib ; rm -rf libkpgp.so )
-( cd opt/kde/lib ; ln -sf libkpgp.so.4 libkpgp.so )
-( cd opt/kde/lib ; rm -rf libksieve.so.4 )
-( cd opt/kde/lib ; ln -sf libksieve.so.4.3.0 libksieve.so.4 )
-( cd opt/kde/lib ; rm -rf libksieve.so )
-( cd opt/kde/lib ; ln -sf libksieve.so.4 libksieve.so )
-( cd opt/kde/lib ; rm -rf libkontactinterfaces.so.4 )
-( cd opt/kde/lib ; ln -sf libkontactinterfaces.so.4.3.0 libkontactinterfaces.so.4 )
-( cd opt/kde/lib ; rm -rf libkontactinterfaces.so )
-( cd opt/kde/lib ; ln -sf libkontactinterfaces.so.4 libkontactinterfaces.so )
-( cd opt/kde/lib ; rm -rf libmimelib.so.4 )
-( cd opt/kde/lib ; ln -sf libmimelib.so.4.3.0 libmimelib.so.4 )
-( cd opt/kde/lib ; rm -rf libmimelib.so )
-( cd opt/kde/lib ; ln -sf libmimelib.so.4 libmimelib.so )
-( cd opt/kde/lib ; rm -rf libkgroupwarebase.so.4 )
-( cd opt/kde/lib ; ln -sf libkgroupwarebase.so.4.3.0 libkgroupwarebase.so.4 )
-( cd opt/kde/lib ; rm -rf libkgroupwarebase.so )
-( cd opt/kde/lib ; ln -sf libkgroupwarebase.so.4 libkgroupwarebase.so )
-( cd opt/kde/lib ; rm -rf libkgroupwaredav.so.4 )
-( cd opt/kde/lib ; ln -sf libkgroupwaredav.so.4.3.0 libkgroupwaredav.so.4 )
-( cd opt/kde/lib ; rm -rf libkgroupwaredav.so )
-( cd opt/kde/lib ; ln -sf libkgroupwaredav.so.4 libkgroupwaredav.so )
-( cd opt/kde/lib ; rm -rf libkcal_resourceblog.so.4 )
-( cd opt/kde/lib ; ln -sf libkcal_resourceblog.so.4.3.0 libkcal_resourceblog.so.4 )
-( cd opt/kde/lib ; rm -rf libkcal_resourceblog.so )
-( cd opt/kde/lib ; ln -sf libkcal_resourceblog.so.4 libkcal_resourceblog.so )
-( cd opt/kde/lib ; rm -rf libkcal_resourceremote.so.4 )
-( cd opt/kde/lib ; ln -sf libkcal_resourceremote.so.4.3.0 libkcal_resourceremote.so.4 )
-( cd opt/kde/lib ; rm -rf libkcal_resourceremote.so )
-( cd opt/kde/lib ; ln -sf libkcal_resourceremote.so.4 libkcal_resourceremote.so )
-( cd opt/kde/lib ; rm -rf libkabckolab.so.4 )
-( cd opt/kde/lib ; ln -sf libkabckolab.so.4.3.0 libkabckolab.so.4 )
-( cd opt/kde/lib ; rm -rf libkabckolab.so )
-( cd opt/kde/lib ; ln -sf libkabckolab.so.4 libkabckolab.so )
-( cd opt/kde/lib ; rm -rf libknoteskolab.so.4 )
-( cd opt/kde/lib ; ln -sf libknoteskolab.so.4.3.0 libknoteskolab.so.4 )
-( cd opt/kde/lib ; rm -rf libknoteskolab.so )
-( cd opt/kde/lib ; ln -sf libknoteskolab.so.4 libknoteskolab.so )
-( cd opt/kde/lib ; rm -rf libkcalkolab.so.4 )
-( cd opt/kde/lib ; ln -sf libkcalkolab.so.4.3.0 libkcalkolab.so.4 )
-( cd opt/kde/lib ; rm -rf libkcalkolab.so )
-( cd opt/kde/lib ; ln -sf libkcalkolab.so.4 libkcalkolab.so )
-( cd opt/kde/lib ; rm -rf libkabc_xmlrpc.so.4 )
-( cd opt/kde/lib ; ln -sf libkabc_xmlrpc.so.4.3.0 libkabc_xmlrpc.so.4 )
-( cd opt/kde/lib ; rm -rf libkabc_xmlrpc.so )
-( cd opt/kde/lib ; ln -sf libkabc_xmlrpc.so.4 libkabc_xmlrpc.so )
-( cd opt/kde/lib ; rm -rf libkcal_xmlrpc.so.4 )
-( cd opt/kde/lib ; ln -sf libkcal_xmlrpc.so.4.3.0 libkcal_xmlrpc.so.4 )
-( cd opt/kde/lib ; rm -rf libkcal_xmlrpc.so )
-( cd opt/kde/lib ; ln -sf libkcal_xmlrpc.so.4 libkcal_xmlrpc.so )
-( cd opt/kde/lib ; rm -rf libknotes_xmlrpc.so.4 )
-( cd opt/kde/lib ; ln -sf libknotes_xmlrpc.so.4.3.0 libknotes_xmlrpc.so.4 )
-( cd opt/kde/lib ; rm -rf libknotes_xmlrpc.so )
-( cd opt/kde/lib ; ln -sf libknotes_xmlrpc.so.4 libknotes_xmlrpc.so )
-( cd opt/kde/lib ; rm -rf libkabcscalix.so.4 )
-( cd opt/kde/lib ; ln -sf libkabcscalix.so.4.3.0 libkabcscalix.so.4 )
-( cd opt/kde/lib ; rm -rf libkabcscalix.so )
-( cd opt/kde/lib ; ln -sf libkabcscalix.so.4 libkabcscalix.so )
-( cd opt/kde/lib ; rm -rf libknotesscalix.so.4 )
-( cd opt/kde/lib ; ln -sf libknotesscalix.so.4.3.0 libknotesscalix.so.4 )
-( cd opt/kde/lib ; rm -rf libknotesscalix.so )
-( cd opt/kde/lib ; ln -sf libknotesscalix.so.4 libknotesscalix.so )
-( cd opt/kde/lib ; rm -rf libkcalscalix.so.4 )
-( cd opt/kde/lib ; ln -sf libkcalscalix.so.4.3.0 libkcalscalix.so.4 )
-( cd opt/kde/lib ; rm -rf libkcalscalix.so )
-( cd opt/kde/lib ; ln -sf libkcalscalix.so.4 libkcalscalix.so )
-( cd opt/kde/lib ; rm -rf libkslox.so.4 )
-( cd opt/kde/lib ; ln -sf libkslox.so.4.3.0 libkslox.so.4 )
-( cd opt/kde/lib ; rm -rf libkslox.so )
-( cd opt/kde/lib ; ln -sf libkslox.so.4 libkslox.so )
-( cd opt/kde/lib ; rm -rf libkabc_slox.so.4 )
-( cd opt/kde/lib ; ln -sf libkabc_slox.so.4.3.0 libkabc_slox.so.4 )
-( cd opt/kde/lib ; rm -rf libkabc_slox.so )
-( cd opt/kde/lib ; ln -sf libkabc_slox.so.4 libkabc_slox.so )
-( cd opt/kde/lib ; rm -rf libkcal_slox.so.4 )
-( cd opt/kde/lib ; ln -sf libkcal_slox.so.4.3.0 libkcal_slox.so.4 )
-( cd opt/kde/lib ; rm -rf libkcal_slox.so )
-( cd opt/kde/lib ; ln -sf libkcal_slox.so.4 libkcal_slox.so )
-( cd opt/kde/lib ; rm -rf libkcal_groupdav.so.4 )
-( cd opt/kde/lib ; ln -sf libkcal_groupdav.so.4.3.0 libkcal_groupdav.so.4 )
-( cd opt/kde/lib ; rm -rf libkcal_groupdav.so )
-( cd opt/kde/lib ; ln -sf libkcal_groupdav.so.4 libkcal_groupdav.so )
-( cd opt/kde/lib ; rm -rf libkabc_groupdav.so.4 )
-( cd opt/kde/lib ; ln -sf libkabc_groupdav.so.4.3.0 libkabc_groupdav.so.4 )
-( cd opt/kde/lib ; rm -rf libkabc_groupdav.so )
-( cd opt/kde/lib ; ln -sf libkabc_groupdav.so.4 libkabc_groupdav.so )
-( cd opt/kde/lib ; rm -rf libkcalgroupwise.so.4 )
-( cd opt/kde/lib ; ln -sf libkcalgroupwise.so.4.3.0 libkcalgroupwise.so.4 )
-( cd opt/kde/lib ; rm -rf libkcalgroupwise.so )
-( cd opt/kde/lib ; ln -sf libkcalgroupwise.so.4 libkcalgroupwise.so )
-( cd opt/kde/lib ; rm -rf libkabcgroupwise.so.4 )
-( cd opt/kde/lib ; ln -sf libkabcgroupwise.so.4.3.0 libkabcgroupwise.so.4 )
-( cd opt/kde/lib ; rm -rf libkabcgroupwise.so )
-( cd opt/kde/lib ; ln -sf libkabcgroupwise.so.4 libkabcgroupwise.so )
-( cd opt/kde/lib ; rm -rf libgwsoap.so.4 )
-( cd opt/kde/lib ; ln -sf libgwsoap.so.4.3.0 libgwsoap.so.4 )
-( cd opt/kde/lib ; rm -rf libgwsoap.so )
-( cd opt/kde/lib ; ln -sf libgwsoap.so.4 libgwsoap.so )
-#%% begin initialize kdepim-4.3.2
+#%% begin initialize kdepim-4.4.8
 if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
 	/bin/bash /opt/kde/bin/plamo_update_kde.sh
 fi
